@@ -18,7 +18,7 @@ from hbshare.base.data_pro import (hb_api)
 from hbshare.base.upass import (get_token, set_token, is_prod_env)
 
 from hbshare.quant.load_data import (load_calendar_extra, load_funds_data, load_funds_alpha)
-from hbshare.quant.gen_charts import (nav_lines, gen_grid)
+from hbshare.quant.output import (nav_lines, gen_grid)
 
 from hbshare.loader.data_query import (db_data_query)
 from hbshare.loader.data_save import (db_data_save)
