@@ -20,13 +20,15 @@ from hbshare.asset_allocation.macro_index.treasury_yield import TreasuryYield
 from hbshare.asset_allocation.macro_index.bond_trading import BondTrading
 from hbshare.asset_allocation.macro_index.future_data import FutureMarketIndex, FuturePrice
 from hbshare.quant_research.IndexActiveStyleAnalyse import EquityIndexStyleCalculator
+from hbshare.convertible_bond.CBMarketIV import CBMarketIV
 
 w.start()
 
 
 def update_weekly(start_date, end_date):
     """
-    周度更新宏观数据
+    周度更新宏观数据：mac_curr, mac_curr_shibor, mac_credit, mac_inflation, mac_eco_increase,
+                  mac_rates_and_price, mac_market_index
     """
     # 宏观-货币类
     Currency(start_date, end_date).get_construct_result()
@@ -81,9 +83,11 @@ def update_daily(start_date, end_date):
     # 期货商品指数数据
     FutureMarketIndex(start_date, end_date).get_construct_result()
     FuturePrice(start_date, end_date).get_construct_result()
+    # 可转债市场隐含波动率
+    CBMarketIV(start_date.replace('-', ''), end_date.replace('-', '')).get_construct_result()
 
 
 if __name__ == '__main__':
-    update_daily(start_date='2021-09-17', end_date='2021-09-17')
-    # update_monthly('2021-08-10', '2021-08-31')
-    # update_weekly(start_date='2021-08-01', end_date='2021-08-31')
\ No newline at end of file
+    update_daily(start_date='2021-11-11', end_date='2021-11-11')
+    # update_monthly('2021-10-10', '2021-10-31')
+    # update_weekly(start_date='2021-09-01', end_date='2021-10-31')
