@@ -1,7 +1,6 @@
 #!/usr/bin/python
 # coding:utf-8
 from table_gen import generate_table
-from db_cons import sql_write_path_work, sql_user_work
 import pandas as pd
 import numpy as np
 import pymysql
@@ -39,11 +38,8 @@ sql_index = '''(
     )
     '''
 
-sql_info1 = sql_user_work
-sql_path1 = sql_write_path_work['daily']
 
-
-def factor_table_gen(table, sql_info=sql_info1):
+def factor_table_gen(table, sql_info):
     try:
         generate_table(
             database='daily_data',
@@ -59,7 +55,7 @@ def factor_table_gen(table, sql_info=sql_info1):
         print(table + ' exists')
 
 
-def index_table_gen(table, sql_info=sql_info1):
+def index_table_gen(table, sql_info):
     try:
         generate_table(
             database='daily_data',
@@ -75,8 +71,8 @@ def index_table_gen(table, sql_info=sql_info1):
         print(table + ' exists')
 
 
-def index_gen(table_factor='cta_factor', table_index='cta_index', sql_path=sql_path1):
-    index_table_gen(table=table_index)
+def index_gen(sql_path, sql_info, table_factor='cta_factor', table_index='cta_index'):
+    index_table_gen(table=table_index, sql_info=sql_info)
     end_date_all = pd.read_sql_query(
         'select distinct TDATE from ' + table_factor + ' order by TDATE desc limit 1', sql_path
     )
@@ -140,7 +136,7 @@ def index_gen(table_factor='cta_factor', table_index='cta_index', sql_path=sql_p
                 print('\tNo new data')
 
 
-def get_last_position(table, before_date, factor, sql_path=sql_path1):
+def get_last_position(table, before_date, factor, sql_path):
     existing_cal = pd.read_sql_query(
         'select distinct `TDATE` from ' + table + ' where `TDATE`<=' + before_date.strftime('%Y%m%d')
         + ' and `FACTOR`=\'' + factor + '\' order by `TDATE` desc limit 1',
@@ -160,7 +156,7 @@ def get_last_position(table, before_date, factor, sql_path=sql_path1):
         return None
 
 
-def load_factor(factor_name, table='cta_factor', sql_path=sql_path1):
+def load_factor(sql_path, factor_name, table='cta_factor'):
     index = factor_name
 
     data = pd.read_sql_query(
@@ -265,9 +261,10 @@ def factor_plot(data, plot_title):
 
 def factor_compute(
         window_days_list,
+        to_sql_path,
+        sql_info,
         start_date=datetime(2010, 1, 1).date(),
         end_date=datetime.now(),
-        to_sql_path=sql_path1,
         to_table='cta_factor',
         data=None,
         factor_func=None,
@@ -278,7 +275,7 @@ def factor_compute(
     else:
         min_volume = 10000
 
-    factor_table_gen(table=to_table)
+    factor_table_gen(table=to_table, sql_info=sql_info)
 
     for window_days in window_days_list:
         if 'hedge_ratio_list' in kwargs:
@@ -306,7 +303,9 @@ def factor_compute(
 
         else:
             index_name = factor_func.__name__ + '_d' + str(window_days)
-            exist_index = get_last_position(table=to_table, before_date=end_date, factor=index_name)
+            exist_index = get_last_position(
+                table=to_table, before_date=end_date, factor=index_name, sql_path=to_sql_path
+            )
 
             if exist_index is not None:
                 start_date0 = exist_index['TDATE'][0]
