@@ -1,6 +1,5 @@
 import pandas as pd
 from sqlalchemy import create_engine
-from db_cons import sql_write_path_work, sql_user_work
 from datetime import datetime
 from table_gen import generate_table
 import hbshare as hbs
@@ -177,19 +176,13 @@ def trans_data(data, contract_info, data_info=None):
     return df
 
 
-def hsjy_fut_wr(exchanges=None, table='hsjy_fut_wr', db_path=None, sql_info=None, page_size=None):
+def hsjy_fut_wr(db_path, sql_info, exchanges=None, table='hsjy_fut_wr', page_size=None):
     if page_size is None:
         page_size = page_size_con
 
     if exchanges is None:
         exchanges = [HSJY_EXCHANGE_SHFE, HSJY_EXCHANGE_DCE, HSJY_EXCHANGE_CZCE, HSJY_EXCHANGE_INE, HSJY_EXCHANGE_CFFEX]
 
-    if db_path is None:
-        db_path = sql_write_path_work['daily']
-
-    if sql_info is None:
-        sql_info = sql_user_work
-
     try:
         generate_table(
             database='daily_data',
@@ -257,19 +250,13 @@ def hsjy_fut_wr(exchanges=None, table='hsjy_fut_wr', db_path=None, sql_info=None
         print('\tNew data: ' + str(len(df)) + ', JSID: ' + str(latest_jsid))
 
 
-def hsjy_fut_com_info(exchanges=None, table='hsjy_fut_info_c', db_path=None, sql_info=None, page_size=None):
+def hsjy_fut_com_info(db_path, sql_info, exchanges=None, table='hsjy_fut_info_c', page_size=None):
     if page_size is None:
         page_size = page_size_con
 
     if exchanges is None:
         exchanges = [HSJY_EXCHANGE_SHFE, HSJY_EXCHANGE_DCE, HSJY_EXCHANGE_CZCE, HSJY_EXCHANGE_INE, HSJY_EXCHANGE_CFFEX]
 
-    if db_path is None:
-        db_path = sql_write_path_work['daily']
-
-    if sql_info is None:
-        sql_info = sql_user_work
-
     try:
         generate_table(
             database='daily_data',
@@ -347,19 +334,13 @@ def hsjy_fut_com_info(exchanges=None, table='hsjy_fut_info_c', db_path=None, sql
         print('\tNew data: ' + str(len(df)) + ', JSID: ' + str(latest_jsid))
 
 
-def hsjy_fut_pro_info(exchanges=None, table='hsjy_fut_info_p', db_path=None, sql_info=None, page_size=None):
+def hsjy_fut_pro_info(db_path, sql_info, exchanges=None, table='hsjy_fut_info_p', page_size=None):
     if page_size is None:
         page_size = page_size_con
 
     if exchanges is None:
         exchanges = [HSJY_EXCHANGE_SHFE, HSJY_EXCHANGE_DCE, HSJY_EXCHANGE_CZCE, HSJY_EXCHANGE_INE, HSJY_EXCHANGE_CFFEX]
 
-    if db_path is None:
-        db_path = sql_write_path_work['daily']
-
-    if sql_info is None:
-        sql_info = sql_user_work
-
     try:
         generate_table(
             database='daily_data',
@@ -427,7 +408,7 @@ def hsjy_fut_pro_info(exchanges=None, table='hsjy_fut_info_p', db_path=None, sql
 
 
 def hsjy_fut_com(
-        exchanges=None, table='hsjy_fut_com', table_info='hsjy_fut_info_c', db_path=None, sql_info=None, page_size=None
+        db_path, sql_info, exchanges=None, table='hsjy_fut_com', table_info='hsjy_fut_info_c', page_size=None
 ):
     if page_size is None:
         page_size = page_size_con
@@ -435,11 +416,6 @@ def hsjy_fut_com(
     if exchanges is None:
         exchanges = [HSJY_EXCHANGE_SHFE, HSJY_EXCHANGE_DCE, HSJY_EXCHANGE_CZCE, HSJY_EXCHANGE_INE]
 
-    if db_path is None:
-        db_path = sql_write_path_work['daily']
-
-    if sql_info is None:
-        sql_info = sql_user_work
 
     try:
         generate_table(
@@ -496,16 +472,10 @@ def hsjy_fut_com(
         print('\tNew data: ' + str(len(df)) + ', JSID: ' + str(latest_jsid))
 
 
-def hsjy_fut_member(table='hsjy_fut_memberrank', db_path=None, sql_info=None, page_size=None):
+def hsjy_fut_member(db_path, sql_info, table='hsjy_fut_memberrank', page_size=None):
     if page_size is None:
         page_size = page_size_con
 
-    if db_path is None:
-        db_path = sql_write_path_work['daily']
-
-    if sql_info is None:
-        sql_info = sql_user_work
-
     try:
         generate_table(
             database='daily_data',
@@ -566,10 +536,3 @@ def hsjy_fut_member(table='hsjy_fut_memberrank', db_path=None, sql_info=None, pa
         latest_jsid = df['JSID'].tolist()[-1]
         print('\tNew data: ' + str(len(df)) + ', JSID: ' + str(latest_jsid))
 
-
-if __name__ == '__main__':
-    hsjy_fut_pro_info()
-    hsjy_fut_wr()
-    hsjy_fut_com_info()
-    hsjy_fut_com()
-    hsjy_fut_member()
