@@ -15,7 +15,7 @@ pymysql.install_as_MySQLdb()
 # 计算每只产品的年化收益，年华波动，夏普，最大回撤等指标
 def performance_analysis(
         data_df, risk_free=0.015, start_date=datetime(2019, 1, 1).date(), end_date=datetime.now().date(),
-        ret_num_per_year=52, monthly_funds=None
+        ret_num_per_year=52, monthly_funds=None, print_info=True
 ):
     if monthly_funds is None:
         monthly_funds = []
@@ -44,7 +44,8 @@ def performance_analysis(
 
         single_data = single_df[single_df[i] > 0]
         if len(single_data) > 1:
-            print('\t计算 ' + i + ' 指标')
+            if print_info:
+                print('\t计算 ' + i + ' 指标')
             start_index = single_data.index[0]
             single_df = single_df.iloc[start_index:].reset_index(drop=True)
 
@@ -83,7 +84,10 @@ def performance_analysis(
                 'downside_risk'
             ] = 0
             downside_vol = np.std(single_df['downside_risk'][1:], ddof=1) * np.sqrt(ret_num_per_year)
-            sharpe = (annualized_return - risk_free) / annualized_vol
+            if annualized_vol == 0:
+                sharpe = np.nan
+            else:
+                sharpe = (annualized_return - risk_free) / annualized_vol
             if downside_vol != 0:
                 sortino = (annualized_return - risk_free) / downside_vol
             else:
@@ -264,10 +268,14 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None):
             ret_this_week.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 2] - 1)
             ret_last_week.append(single_df[i][len(single_df) - 2] / single_df[i][len(single_df) - 3] - 1)
             ret_this_4.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 5] - 1)
-            ret_this_8.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 9] - 1)
+            try:
+                ret_this_8.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 9] - 1)
+            except KeyError:
+                ret_this_8.append(None)
+
             try:
                 ret_6_months.append(single_df[i][len(single_df) - 1] / single_df[i][len(single_df) - 25] - 1)
-            except:
+            except KeyError:
                 ret_6_months.append(None)
         else:
             ret_this_week.append(None)
@@ -282,20 +290,32 @@ def performance_specific_ret(data_df, form=True, monthly_funds=None):
         ].reset_index(drop=True)
         nav_2018 = nav_2018[nav_2018[i] > 0].reset_index(drop=True)
 
+        if len(nav_2018) > 0:
+            end_date_2018 = nav_2018[date_col].tolist()[-1]
+        else:
+            end_date_2018 = datetime(2018, 12, 28).date()
         nav_2019 = single_df[
             np.array(single_df[date_col] < datetime(2020, 1, 1).date())
-            & np.array(single_df[date_col] >= datetime(2018, 12, 28).date())
+            & np.array(single_df[date_col] >= end_date_2018)
         ].reset_index(drop=True)
         nav_2019 = nav_2019[nav_2019[i] > 0].reset_index(drop=True)
 
+        if len(nav_2019) > 0:
+            end_date_2019 = nav_2019[date_col].tolist()[-1]
+        else:
+            end_date_2019 = datetime(2019, 12, 27).date()
         nav_2020 = single_df[
             np.array(single_df[date_col] < datetime(2021, 1, 1).date())
-            & np.array(single_df[date_col] >= datetime(2019, 12, 27).date())
+            & np.array(single_df[date_col] >= end_date_2019)
         ].reset_index(drop=True)
         nav_2020 = nav_2020[nav_2020[i] > 0].reset_index(drop=True)
 
+        if len(nav_2020) > 0:
+            end_date_2020 = nav_2020[date_col].tolist()[-1]
+        else:
+            end_date_2020 = datetime(2020, 12, 31).date()
         nav_2021 = single_df[
-            np.array(single_df[date_col] >= datetime(2020, 12, 31).date())
+            np.array(single_df[date_col] >= end_date_2020)
         ].reset_index(drop=True)
         nav_2021 = nav_2021[nav_2021[i] > 0].reset_index(drop=True)
 
