@@ -1,5 +1,5 @@
 #!/usr/bin/python
-#coding:utf-8
+# coding:utf-8
 import pandas as pd
 import numpy as np
 from sqlalchemy import create_engine
@@ -14,11 +14,13 @@ from hbshare.quant.cons import (
     HSJY_EXCHANGE_CZCE,
     HSJY_EXCHANGE_SHFE,
     HSJY_EXCHANGE_DCE,
-    HSJY_EXCHANGE_CFFEX
+    HSJY_EXCHANGE_CFFEX,
+    wind_sec
 )
 from hbshare.quant.load_data import load_calendar_extra
 import hbshare as hbs
 import pymysql
+import re
 
 pymysql.install_as_MySQLdb()
 
@@ -122,98 +124,49 @@ def wind_product_index_sigma_xs(
     return result
 
 
-def wind_com_fut_sec_index_amount(
+def wind_com_fut_sec_index(
         db_path,
         start_date=datetime(2015, 1, 1).date(),
         end_date=datetime.now().date(),
         table='commodities_index_wind',
         decimal=100000000,
-        freq='',
+        key='amount',
 ):
     engine = create_engine(db_path)
     data = pd.read_sql_query(
-        'select `code`, `name`, `t_date`, `close`, `product`, `volume`, `amount` from ' + table
+        'select `code`, `name`, `t_date`, `close`, `product`, `volume`, `amount`, `oi_amount` from ' + table
         + ' where `t_date`<=' + end_date.strftime('%Y%m%d')
         + ' and `t_date`>=' + start_date.strftime('%Y%m%d')
         + ' and `product` in (\'index\') and `code`!=\'CCFI.WI\' order by `t_date`',
         engine
     )
-    code_list = data['name'].drop_duplicates().tolist()
-    date_df = data[['t_date']].drop_duplicates().reset_index(drop=True)
-    if freq == '':
-        amount_df = date_df.copy(deep=True)
-        for i in code_list:
-            data_i = data[data['name'] == i].reset_index().rename(columns={'amount': i})
-            data_i[i] = data_i[i] / decimal
-            data_i.loc[
-                data_i['t_date'] < datetime(2020, 1, 1).date(), i
-            ] = data_i[
-                        data_i['t_date'] < datetime(2020, 1, 1).date()
-                    ][i] / 2
-            amount_df = amount_df.merge(data_i[['t_date', i]], on='t_date', how='left')
-
-    else:
-        amount_df = None
-        for i in code_list:
-            data_i = data[data['name'] == i].reset_index().rename(columns={'amount': i})[[i, 't_date']]
-            data_i[i] = data_i[i] / decimal
-            data_i.loc[
-                data_i['t_date'] < datetime(2020, 1, 1).date(), i
-            ] = data_i[
-                    data_i['t_date'] < datetime(2020, 1, 1).date()
-                    ][i] / 2
-            data_i_s = pd.Series(data_i[i].tolist(), index=pd.to_datetime(data_i['t_date']))
-            data_i_ranged = pd.DataFrame(data_i_s.resample(freq).mean().round(2)).rename(columns={0: i})
-            if amount_df is None:
-                amount_df = data_i_ranged
-            else:
-                amount_df = pd.concat([amount_df, data_i_ranged], axis=1)
-        amount_df['t_date'] = pd.to_datetime(amount_df.reset_index()['t_date']).dt.date.tolist()
-        amount_df = amount_df.reset_index(drop=True)
-    return amount_df
+    data['code'] = data['code'].apply(lambda x: wind_sec[x])
+    df = data.pivot(index='t_date', columns='code', values=key)
+    df /= decimal
+    df.loc[df.index < datetime(2020, 1, 1).date(), :] = df.loc[df.index < datetime(2020, 1, 1).date(), :] / 2
+    return df.reset_index()
 
 
-def wind_index_fut_amount(
+def wind_fin_fut_index(
         db_path,
         start_date=datetime(2015, 1, 1).date(),
         end_date=datetime.now().date(),
         table='futures_wind',
         decimal=100000000,
-        freq='',
+        key='amount',
 ):
     engine = create_engine(db_path)
     data = pd.read_sql_query(
-        'select `code`, `symbol`, `t_date`, `close`, `product`, `volume`, `amount` from ' + table
+        'select `code`, `symbol`, `t_date`, `close`, `product`, `volume`, `amount`, `oi_amount` from ' + table
         + ' where `t_date`<=' + end_date.strftime('%Y%m%d')
         + ' and `t_date`>=' + start_date.strftime('%Y%m%d')
-        + ' and `product` in (\'IC\', \'IF\', \'IH\') order by `t_date`, `product`',
+        + ' and `product` in (\'IC\', \'IF\', \'IH\', \'T\', \'TF\', \'TS\') order by `t_date`, `product`',
         engine
     )
-    code_list = data['product'].drop_duplicates().tolist()
-    date_df = data[['t_date']].drop_duplicates().reset_index(drop=True)
-    if freq == '':
-        amount_df = date_df.copy(deep=True)
-        for i in code_list:
-            data_i = data[data['product'] == i].reset_index().rename(columns={'amount': i})
-            data_i[i] = data_i[i] / decimal
-            data_i_grouped = data_i[['t_date', i]].groupby('t_date').sum().round(2).reset_index()
-            amount_df = amount_df.merge(data_i_grouped[['t_date', i]], on='t_date', how='left')
-    else:
-        amount_df = None
-        for i in code_list:
-            data_i = data[data['product'] == i].reset_index().rename(columns={'amount': i})
-            data_i[i] = data_i[i] / decimal
-            data_i_grouped = data_i[['t_date', i]].groupby('t_date').sum().round(2).reset_index()
-            data_i_s = pd.Series(data_i_grouped[i].tolist(), index=pd.to_datetime(data_i_grouped['t_date']))
-            data_i_ranged = pd.DataFrame(data_i_s.resample(freq).mean().round(2)).rename(columns={0: i})
-            if amount_df is None:
-                amount_df = data_i_ranged
-            else:
-                amount_df = pd.concat([amount_df, data_i_ranged], axis=1)
-        amount_df['t_date'] = pd.to_datetime(amount_df.reset_index()['t_date']).dt.date.tolist()
-        amount_df = amount_df.reset_index(drop=True)
-
-    return amount_df
+    data = data[['t_date', 'product', key]].groupby(by=['t_date', 'product']).sum().round(2).reset_index()
+    df = data.pivot(index='t_date', columns='product', values=key)
+    df /= decimal
+    return df.reset_index()
 
 
 def fin_fut_daily_k_by_contracts(contract_list, start_date=None, end_date=None, page_size=None):
@@ -309,3 +262,41 @@ def fut_com_amount_by_ex(start_date=None, end_date=None, page_size=None):
             data['data'] = data['data'] + hbs.db_data_query(db=db, sql=sql, page_size=page_size, page_num=p)['data']
 
     return data
+
+
+def rolling_volatility(data, vol_params=None):
+    if vol_params is None:
+        vol_params = [
+            '20日', '30日', '60日', '90日', '120日', '150日', '200日'
+        ]
+
+    vol_max = []
+    vol_75 = []
+    vol_50 = []
+    vol_25 = []
+    vol_min = []
+    vol_current = []
+
+    for i in vol_params:
+        data[i] = data['ret'].rolling(int(re.findall(r'\d+', i)[0])).std(ddof=1) * np.sqrt(250) * 100
+        vol_max.append(np.nanmax(data[str(i)]))
+        vol_75.append(np.nanpercentile(data[str(i)], 75))
+        vol_50.append(np.nanpercentile(data[str(i)], 50))
+        vol_25.append(np.nanpercentile(data[str(i)], 25))
+        vol_min.append(np.nanmin(data[str(i)]))
+        vol_current.append(data[str(i)].tolist()[-1])
+
+    vol_data = pd.DataFrame(
+        {
+            '时间': vol_params,
+            '最大值': vol_max,
+            '75分位': vol_75,
+            '中位值': vol_50,
+            '25分位': vol_25,
+            '最小值': vol_min,
+            '最新值': vol_current
+        }
+    )
+    return vol_data, data
+
+
