@@ -284,7 +284,7 @@ def load_funds_alpha(
     return result
 
 
-# 跟踪池标的传入HBDB
+# 跟踪池标的列表传入HBDB
 def fund_pool_to_hb(fund_df, table='fund_pool', sql_path='', sql_ip='', sql_user='', sql_pass='', database=''):
     sql_l = '''
     (
@@ -310,4 +310,58 @@ def fund_pool_to_hb(fund_df, table='fund_pool', sql_path='', sql_ip='', sql_user
     fund_df.to_sql(table, sql_path, if_exists='append', index=False)
 
 
+# 跟踪池标的净值传入HBDB
+def fund_data_to_hb(path_local, path_hb, sql_hb, database, tables=None):
+    # engine_work = create_engine(sql_write_path_work['work'])
+    # engine_hb = create_engine(sql_write_path_hb['work'])
+
+    if tables is None:
+        tables = [
+            'fund_data',
+            'fund_list',
+        ]
+
+    for t in tables:
+        print(t)
+
+        id_in_hb = pd.read_sql_query(
+            'select `id` from ' + t + ' order by `id` desc', path_hb
+        )
+        id_in_local = pd.read_sql_query(
+            'select `id` from ' + t + ' order by `id` desc', path_local
+        )
+
+        id_hb_diff = set(id_in_hb['id']).difference(set(id_in_local['id']))
+        if len(id_hb_diff) > 0:
+            db_hb = pymysql.connect(sql_hb['ip'], sql_hb['user'], sql_hb['pass'], database)
+            cursor = db_hb.cursor()
+            if len(id_hb_diff) > 1:
+                cursor.execute(
+                    'delete from ' + t + ' where `id` in ' + str(tuple(id_hb_diff))
+                )
+            else:
+                cursor.execute(
+                    'delete from ' + t + ' where `id`=' + str(list(id_hb_diff)[0])
+                )
+            db_hb.commit()
+            db_hb.close()
+            print('\tdelete: ' + str(len(id_hb_diff)))
+
+        data_hb_last_one = pd.read_sql_query(
+            'select `id` from ' + t + ' order by `id` desc limit 1', path_hb
+        )
+        if len(data_hb_last_one) > 0:
+            id_num = data_hb_last_one['id'][0]
+        else:
+            id_num = -1
+
+        data_work_new = pd.read_sql_query(
+            'select * from ' + t + ' where `id`>' + str(id_num), path_local
+        )
+
+        data_work_new.to_sql(t, path_hb, if_exists='append', index=False)
+
+        print('\tnew data: ' + str(len(data_work_new)))
+
+
 
