@@ -351,11 +351,13 @@ class StyleAttribution:
 
 if __name__ == '__main__':
     # 公募样例：110011
-    res = StyleAttribution(fund_id='110011', fund_type='mutual', start_date='20181120', end_date='20210120',
-                           factor_type='style', benchmark_id='000300', nav_frequency='day').get_all(processed=False)
+    # res = StyleAttribution(fund_id='001975', fund_type='mutual', start_date='20201231', end_date='20211015',
+    #                        factor_type='style_allo', benchmark_id='000985', nav_frequency='day').get_all(processed=False)
     # 私募样例
-    # res = StyleAttribution(fund_id='SGX346', fund_type='private', start_date='20210104', end_date='20210813',
-    #                        factor_type='style', benchmark_id='000905', nav_frequency='day').get_all()
+    # res = StyleAttribution(fund_id='SGK768', fund_type='private', start_date='20190419', end_date='20211021',
+    #                        factor_type='style_allo', benchmark_id='000985', nav_frequency='week').get_all()
+    res = StyleAttribution(fund_id='SX8958', fund_type='private', start_date='20180112', end_date='20211021',
+                           factor_type='style_allo', benchmark_id='000985', nav_frequency='week').get_all()
     # res = StyleAttribution(fund_id='SR4480', fund_type='private', start_date='20191220', end_date='20210702',
     #                        factor_type='style', benchmark_id='000985', nav_frequency='week').get_all(processed=False)
-    print(res['exposure_series'])
+    print(res['attr_df'])
