@@ -19,6 +19,31 @@ engine_params = "mysql+pymysql://{}:{}@{}:{}/{}".format(sql_params['user'], sql_
                                                         sql_params['port'], sql_params['database'])
 
 
+def get_trading_day_list(start_date, end_date, frequency='day'):
+    sql_script = "SELECT JYRQ, SFJJ, SFZM, SFYM FROM funddb.JYRL WHERE JYRQ >= {} and JYRQ <= {}".format(
+        start_date, end_date)
+    res = hbs.db_data_query('readonly', sql_script, page_size=5000)
+    df = pd.DataFrame(res['data']).rename(
+        columns={"JYRQ": 'calendarDate', "SFJJ": 'isOpen',
+                 "SFZM": "isWeekEnd", "SFYM": "isMonthEnd"}).sort_values(by='calendarDate')
+    df['isOpen'] = df['isOpen'].astype(int).replace({0: 1, 1: 0})
+    df['isWeekEnd'] = df['isWeekEnd'].fillna(0).astype(int)
+    df['isMonthEnd'] = df['isMonthEnd'].fillna(0).astype(int)
+
+    calendar_df = df[['calendarDate', 'isOpen', 'isWeekEnd', 'isMonthEnd']]
+
+    if frequency == "day":
+        trading_day_list = calendar_df[calendar_df['isOpen'] == 1]['calendarDate'].tolist()
+    elif frequency == "week":
+        trading_day_list = calendar_df[calendar_df['isWeekEnd'] == 1]['calendarDate'].tolist()
+    elif frequency == 'month':
+        trading_day_list = calendar_df[calendar_df['isMonthEnd'] == 1]['calendarDate'].tolist()
+    else:
+        trading_day_list = calendar_df['calendarDate'].tolist()
+
+    return trading_day_list
+
+
 class NavAttributionLoader:
     def __init__(self, fund_id, fund_type, start_date, end_date, factor_type, benchmark_id):
         self.fund_id = fund_id
@@ -32,7 +57,7 @@ class NavAttributionLoader:
     def _init_api_params(self):
         self.url = 'http://fdc-query.intelnal.howbuy.com/query/data/commonapi?dataTrack=xxxxx'
         self.headers = {'Content-Type': 'application/json'}
-        self.post_body = {"database": "readonly", "sql": None}
+        self.post_body = {"database": "readonly"}
 
     def fetch_data_batch(self, sql_script):
         post_body = self.post_body.copy()
@@ -94,14 +119,12 @@ class NavAttributionLoader:
             data = pd.DataFrame(res['data'])
             data['ADJ_NAV'] = 0.01 * data['ACCUMULATE_RETURN'] + 1
         else:
-            sql_script = "SELECT a.jjdm fund_id, b.jzrq tradeDate, b.fqdwjz as adj_nav from " \
-                         "fundapp.jjxx1 a, fundapp.smlj b where a.cpfl = '4' and a.jjdm = b.jjdm " \
+            sql_script = "SELECT a.jjdm fund_id, b.jzrq TRADEDATE, b.fqdwjz as ADJ_NAV from " \
+                         "st_hedge.t_st_jjxx a, st_hedge.t_st_rhb b where a.cpfl = '4' and a.jjdm = b.jjdm " \
                          "and a.jjzt not in ('3') " \
                          "and a.jjdm = '{}' and b.jzrq >= {} and b.jzrq <= {} " \
                          "order by b.jzrq".format(self.fund_id, self.start_date, self.end_date)
-            post_body = self.post_body
-            post_body['sql'] = sql_script
-            res = requests.post(url=self.url, data=json.dumps(post_body), headers=self.headers).json()
+            res = hbs.db_data_query("highuser", sql_script, page_size=5000)
             data = pd.DataFrame(res['data'])
 
         data.rename(columns={"FUND_ID": "fund_id", "TRADEDATE": "tradeDate", "ADJ_NAV": "adj_nav"}, inplace=True)
@@ -245,12 +268,12 @@ class CtaNavAttributionLoader:
         return all_data
 
     def _load_fund_data(self):
-        sql_script = "SELECT a.jjdm fund_id, b.jzrq tradeDate, b.fqdwjz as adj_nav from " \
-                     "fundapp.jjxx1 a, fundapp.smlj b where a.cpfl = '4' and a.jjdm = b.jjdm " \
+        sql_script = "SELECT a.jjdm fund_id, b.jzrq TRADEDATE, b.fqdwjz as ADJ_NAV from " \
+                     "st_hedge.t_st_jjxx a, st_hedge.t_st_rhb b where a.cpfl = '4' and a.jjdm = b.jjdm " \
                      "and a.jjzt not in ('3') " \
                      "and a.jjdm = '{}' and b.jzrq >= {} and b.jzrq <= {} " \
-                     "order by b.jzrq".format(self.fund_id, self.pre_date, self.end_date)
-        res = hbs.db_data_query('readonly', sql_script)
+                     "order by b.jzrq".format(self.fund_id, self.start_date, self.end_date)
+        res = hbs.db_data_query("highuser", sql_script, page_size=5000)
         data = pd.DataFrame(res['data']).rename(
             columns={"FUND_ID": "fund_id", "TRADEDATE": "tradeDate", "ADJ_NAV": "adj_nav"})
 
@@ -857,18 +880,22 @@ class MorningStarBoxStyleLoader:
         估值数据
         """
         # 主板
-        sql_script = "SELECT (select a.SecuCode from hsjy_gp.SecuMain a where a.InnerCode = b.InnerCode " \
-                     "and rownum = 1 and a.SecuMarket in (83, 90) and a.SecuCategory = 1) SecuCode, " \
-                     "b.TotalMV, b.NegotiableMV, b.PE, b.PB, b.PCFTTM, b.DividendRatio FROM " \
-                     "hsjy_gp.LC_DIndicesForValuation b WHERE b.TradingDay = to_date('{}', 'yyyymmdd')".format(date)
+        sql_script = "SELECT TotalMV, NegotiableMV, PE, PB, PCFTTM, DividendRatio, SecuCode FROM " \
+                     "(SELECT b.TotalMV, b.NegotiableMV, b.PE, b.PB, b.PCFTTM, b.DividendRatio, a.SecuCode, " \
+                     "row_number() over(partition by a.InnerCode order by a.InnerCode) rn FROM " \
+                     "hsjy_gp.LC_DIndicesForValuation b join hsjy_gp.SecuMain a on a.InnerCode = b.InnerCode and " \
+                     "a.SecuMarket in (83, 90) and a.SecuCategory = 1 WHERE b.TradingDay = to_date('{}', 'yyyymmdd')) " \
+                     "WHERE rn = 1".format(date)
         data_main = self.fetch_data_batch('readonly', sql_script)
         data_main.rename(columns={"SECUCODE": "ticker", "TOTALMV": "marketValue",
                                   "NEGOTIABLEMV": "negMarketValue", "PCFTTM": "PCF"}, inplace=True)
         # 科创板
-        sql_script = "SELECT (select a.SecuCode from hsjy_gp.SecuMain a where a.InnerCode = b.InnerCode " \
-                     "and rownum = 1 and a.SecuMarket in (83, 90) and a.SecuCategory = 1) SecuCode, " \
-                     "b.TotalMV, b.NegotiableMV, b.PETTM, b.PB, b.PCFTTM, b.DividendRatio FROM " \
-                     "hsjy_gp.LC_STIBDIndiForValue b WHERE b.TradingDay = to_date('{}', 'yyyymmdd')".format(date)
+        sql_script = "SELECT TotalMV, NegotiableMV, PETTM, PB, PCFTTM, DividendRatio, SecuCode FROM " \
+                     "(SELECT b.TotalMV, b.NegotiableMV, b.PETTM, b.PB, b.PCFTTM, b.DividendRatio, a.SecuCode, " \
+                     "row_number() over(partition by a.InnerCode order by a.InnerCode) rn FROM " \
+                     "hsjy_gp.LC_STIBDIndiForValue b join hsjy_gp.SecuMain a on a.InnerCode = b.InnerCode and " \
+                     "a.SecuMarket in (83, 90) and a.SecuCategory = 1 WHERE b.TradingDay = to_date('{}', 'yyyymmdd')) " \
+                     "WHERE rn = 1".format(date)
         res = hbs.db_data_query('readonly', sql_script)
         data_stib = pd.DataFrame(res['data'])
         data_stib.rename(
@@ -877,6 +904,7 @@ class MorningStarBoxStyleLoader:
 
         data = pd.concat([data_main, data_stib])
         del data['ROW_ID']
+        data = data.dropna(subset=['ticker'])
 
         return data.set_index('ticker')
 
